geowatch.tasks.fusion.datamodules.temporal\_sampling.affinity\_sampling module
==============================================================================

.. automodule:: geowatch.tasks.fusion.datamodules.temporal_sampling.affinity_sampling
   :members:
   :undoc-members:
   :show-inheritance:
